<?php
/**
 * JEvents Locations Component for Joomla 1.5.x
 *
 * @version     $Id: jevmenu.php 2035 2011-05-10 10:09:06Z geraintedwards $
 * @package     JEvents
 * @copyright   Copyright (C) 2008-2009 GWE Systems Ltd
 * @license     GNU/GPLv2, see http://www.gnu.org/licenses/gpl-2.0.html
 * @link        http://www.jevents.net
 */

// Check to ensure this file is included in Joomla!

defined('JPATH_BASE') or die;

use Joomla\CMS\Language\Text;
use Joomla\CMS\Form\FormHelper;
use Joomla\CMS\Factory;

jimport('joomla.html.html');
jimport('joomla.form.formfield');
jimport('joomla.form.helper');
FormHelper::loadFieldClass('list');
include_once(JPATH_ADMINISTRATOR."/components/com_jevents/jevents.defines.php");


class JFormFieldJEVmenu extends JFormFieldList
{

	protected $type = 'JEVmenu';

	public function getOptions()
	{
		// Trap to stop the config from being editing from the categories page
		if (Factory::getApplication()->input->getString("option") =="com_config" && Factory::getApplication()->input->getString("component") =="com_categories"){
			?>
			<script type="text/javascript">
				window.parent.SqueezeBox.close();
			</script>
			<?php
			exit();
		}		

		return JFormFieldJEVmenu::fetchElement($this->name, $this->value, $this->element, $this->type, true);  // RSH 10/4/10 - Use the original code for J!1.6
	}
	
	public static function getInputStatic($name, $value, &$node, $control_name, $raw=false){		

		return JFormFieldJEVmenu::fetchElement($name, $value, $node, $control_name, $raw);
	}
        
    static function fetchElement($name, $value, &$node, $control_name, $raw=false)  // RSH 10/20/10 - Added raw parameter to return just the elements for J!1.6
	{

		// Must load admin language files
		$lang = Factory::getLanguage();
		$lang->load("com_jevlocations", JPATH_ADMINISTRATOR);

		$db = Factory::getDBO();

		// assemble menu items to the array
		$options 	= array();
		$options[]	= JHTML::_('select.option', '', '- '.Text::_('COM_JEVLOCATIONS_SELECT_ITEM').' -');
		
		// load the list of menu types
		// TODO: move query to model
		$query = 'SELECT menutype, title' .
				' FROM #__menu_types' .
				' ORDER BY title';
		$db->setQuery( $query );
		$menuTypes = $db->loadObjectList();

		$menu =  Factory::getApplication()->getMenu('site', $options);
		$coremenuItems =  $menu->getMenu();
		$extension = isset($node) ? (string) $node->attributes()->extension : false ;
		if (!$extension) {
			$extension = "com_jevents";
		}
		// must make a copy otherwise by changing the referenced original 
		// it affects the menu modules !!!
		$menuItems = array();
		foreach ($coremenuItems as $coreitem)
		{
		 	$item = clone $coreitem;
			if ($item->component ==$extension)
			{
					$item->title  = "*** ".$item->title." ***";
			}
			$menuItems[] = $item;
		} 
				
		// establish the hierarchy of the menu
		$children = array();

		if ($menuItems)
		{
			// first pass - collect children
			foreach ($menuItems as $v)
			{
				$pt 	= 0; // RSH 10/4/10 in J!1.5 - parent was always 0, this changed in J!.16 to a real parent_id, so force id to 0 for compatibility instead of $v->parent;
				$list 	= @$children[0] ? $children[0] : array();
				array_push( $list, $v );
				$children[0] = $list;  // RSH use '0' instead of $pt
			}
		}

		// second pass - get an indent list of the items
		$list = JHTML::_('menu.treerecurse', 0, '', array(), $children, 9999, 0, 0 );

		// assemble into menutype groups
		$n = count( $list );
		$groupedList = array();
		foreach ($list as $k => $v) {
			$groupedList[$v->menutype][] = &$list[$k];
		}

		foreach ($menuTypes as $type)
		{
			$options[]	= JHTML::_('select.option',  $type->menutype, $type->title , 'value', 'text', true );
			if (isset( $groupedList[$type->menutype] ))
			{
				$n = count( $groupedList[$type->menutype] );
				for ($i = 0; $i < $n; $i++)
				{
					$item = &$groupedList[$type->menutype][$i];
					
					//If menutype is changed but item is not saved yet, use the new type in the list
					if ( Factory::getApplication()->input->getString('option', '', 'get') == 'com_menus' ) {
						$currentItemArray = Factory::getApplication()->input->get('cid', array(0), 'array');
						$currentItemId = (int) $currentItemArray[0];
						$currentItemType = Factory::getApplication()->input->getString('type', $item->type, 'get');
						if ( $currentItemId == $item->id && $currentItemType != $item->type) {
							$item->type = $currentItemType;
						}
					}
					
					$disable = false; //strpos($node->attributes('disable'), $item->type) !== false ? true : false;
					$text = '&nbsp;&nbsp;&nbsp;' . html_entity_decode($item->treename, ENT_COMPAT, "UTF-8");  // RSH 10/4/10 - J!1.6 does a htmlspecialentities and html_entity_decode to screw up the text!  Make sure the correct values are passed for the respective versions
					$options[] = JHTML::_('select.option',  $item->id, $text , 'value', 'text', $disable );

				}
			}
		}

		if ($raw) {
			return $options;
		} else {
		return JHTML::_('select.genericlist',  $options, ''.$control_name.'['.$name.']', 'class="inputbox"', 'value', 'text', $value, $control_name.$name);
		}
		
	}
}
